@@ -834,42 +834,14 @@ create_language_section (EphyDialog *dialog)
 static void
 download_path_changed_cb (GtkFileChooser *button)
 {
-	char *dir, *downloads_dir, *desktop_dir;
+	char *dir;
 
-	/* FIXME: use _uri variant when we support downloading 
-	 * to gnome-vfs remote locations
-	 */
 	dir = gtk_file_chooser_get_filename (button);
 	if (dir == NULL) return;
 
-	downloads_dir = ephy_file_downloads_dir ();
-	desktop_dir = ephy_file_desktop_dir ();
-	g_return_if_fail (downloads_dir != NULL && desktop_dir != NULL);
-
-	/* Check if the dir matches the default downloads_dir or desktop_dir to
-	 * store the english name instead of the localized one reported by the
-	 * two ephy_file_ functions. */
-	if (strcmp (dir, downloads_dir) == 0)
-	{
-		g_settings_set_string (EPHY_SETTINGS_STATE,
-				       EPHY_PREFS_STATE_DOWNLOAD_DIR,
-				       _("Downloads"));
-	}
-	else if (strcmp (dir, desktop_dir) == 0)
-	{
-		g_settings_set_string (EPHY_SETTINGS_STATE,
-				       EPHY_PREFS_STATE_DOWNLOAD_DIR,
-				       _("Desktop"));
-	}
-	else
-	{
-		g_settings_set_string (EPHY_SETTINGS_STATE,
-				       EPHY_PREFS_STATE_DOWNLOAD_DIR, dir);
-	}
-
+	g_settings_set_string (EPHY_SETTINGS_STATE,
+			       EPHY_PREFS_STATE_DOWNLOAD_DIR, dir);
 	g_free (dir);
-	g_free (downloads_dir);
-	g_free (desktop_dir);
 }
 
 static void
@@ -977,18 +949,15 @@ cookies_get_mapping (GValue *value,
 		     gpointer user_data)
 {
 	const char *setting;
-	char *name;
+	const char *name;
 
 	setting = g_variant_get_string (variant, NULL);
-
-	g_object_get (user_data, "name", &name, NULL);
+	name = gtk_buildable_get_name (GTK_BUILDABLE (user_data));
 
 	/* If the button name matches the setting, it should be active. */
 	if (g_strcmp0 (name, setting) == 0)
 		g_value_set_boolean (value, TRUE);
 
-	g_free (name);
-
 	return TRUE;
 }
 
@@ -998,17 +967,15 @@ cookies_set_mapping (const GValue *value,
 		     gpointer user_data)
 {
 	GVariant *variant = NULL;
-	char *name;
+	const char *name;
 
 	/* Don't act unless the button has been activated (turned ON). */
 	if (!g_value_get_boolean (value))
 		return NULL;
 
-	g_object_get (user_data, "name", &name, NULL);
+	name = gtk_buildable_get_name (GTK_BUILDABLE (user_data));
 	variant = g_variant_new_string (name);
 
-	g_free (name);
-
 	return variant;
 }
 
@@ -1076,13 +1043,13 @@ static const PrefsDialogPreference preferences[] =
 	  G_SETTINGS_BIND_DEFAULT, NULL, NULL },
 
 	/* Has mapping */
-	{ "cookies_always_radiobutton", "active",
+	{ "always", "active",
 	  EPHY_PREFS_WEB_SCHEMA, EPHY_PREFS_WEB_COOKIES_POLICY,
 	  G_SETTINGS_BIND_DEFAULT, cookies_get_mapping, cookies_set_mapping },
-	{ "cookies_no_third_party_radiobutton", "active",
+	{ "no-third-party", "active",
 	  EPHY_PREFS_WEB_SCHEMA, EPHY_PREFS_WEB_COOKIES_POLICY,
 	  G_SETTINGS_BIND_DEFAULT, cookies_get_mapping, cookies_set_mapping },
-	{ "cookies_never_radiobutton", "active",
+	{ "never", "active",
 	  EPHY_PREFS_WEB_SCHEMA, EPHY_PREFS_WEB_COOKIES_POLICY,
 	  G_SETTINGS_BIND_DEFAULT, cookies_get_mapping, cookies_set_mapping },
 };
