@@ -27,7 +27,6 @@
 #include "ephy-embed-single.h"
 #include "ephy-embed-utils.h"
 #include "ephy-shell.h"
-#include "ephy-embed-persist.h"
 #include "ephy-debug.h"
 #include "window-commands.h"
 #include "ephy-prefs.h"
@@ -1038,7 +1037,7 @@ window_cmd_help_about (GtkAction *action,
 			    NULL);
 
 	gtk_show_about_dialog (GTK_WINDOW (window),
-			       "name", _("GNOME Web Browser"),
+			       "program-name", _("GNOME Web Browser"),
 			       "version", VERSION,
 			       "copyright", "Copyright © 2002–2004 Marco Pesenti Gritti\n"
 			                    "Copyright © 2003–2010 The GNOME Web Browser Developers",
